@@ -23,7 +23,7 @@
 #include <KLineEdit>
 #include <QTimer>
 #include <QHBoxLayout>
-#include <KLocale>
+#include <KLocalizedString>
 
 #include "kalziumdataobject.h"
 #include "search.h"
@@ -37,7 +37,7 @@ SearchWidget::SearchWidget(QWidget *parent) : QWidget(parent), m_timer(0)
     mainlay->addWidget(new QLabel(i18n("Search:"), this));
 
     m_searchLine = new KLineEdit(this);
-    m_searchLine->setClearButtonShown(true);
+    m_searchLine->setClearButtonEnabled(true);
     m_searchLine->setTrapReturnKey(true);
     connect(m_searchLine, SIGNAL(textChanged(QString)),
              this, SLOT(searchTextChanged(QString)));
@@ -93,5 +93,3 @@ void SearchWidget::doSearch()
         s->resetSearch();
     }
 }
-
-#include "searchwidget.moc"
